/*
 * Copyright (c) 2018 Laczen
 *
 * SPDX-License-Identifier: Apache-2.0
 */


#include <zephyr.h>
#include <misc/reboot.h>
#include <device.h>
#include <string.h>
#include <nvs/nvs.h>
#include <flash.h>

static struct nvs_fs storage;
struct flash_pages_info info;

int nvs_setup1(void)
{
	int err;

	storage.offset = DT_FLASH_AREA_STORAGE_OFFSET;
	err = flash_get_page_info_by_offs(device_get_binding(DT_FLASH_DEV_NAME),
					 storage.offset, &info);
	if (err) {
		printk("Unable to get page info");
	}
	storage.sector_size = info.size;
	storage.sector_count = 3U;

	err = nvs_init(&storage, DT_FLASH_DEV_NAME);
	if (err) {
		printk("Flash Init failed\n");
	}
	return err;
}


void main(void)
{
	int err;

	err = nvs_setup1();
	if(err){
		printk("nvs_setup failed\n");
	}

	nvs_clear(&storage);

	printk("NVS offset: %08x\n", storage.offset);
	printk("NVS ate_wra: %08x\n", storage.ate_wra);
	printk("NVS data_wra: %08x\n", storage.data_wra);
	printk("NVS Sector Size: %u\n", storage.sector_size);
	printk("NVS sector_count: %u\n", storage.sector_count);
	printk("NVS write_block_size: %u\n", storage.write_block_size);
	printk("NVS ready: %d\n", storage.ready);
	ssize_t freespace = nvs_calc_free_space(&storage);
	printk("Remaining free space in nvs sector is %d Bytes\n", freespace);

	char value1[35] = "53.760241,-5.147095,1.023,11:20:22";
	for(int i=0; i<10; i++)
	{
		// printk("Writing %s to NVS\n", results[i]);
		ssize_t bytes_written = nvs_write(&storage, i, value1, strlen(value1)+1);
		printk("Bytes written to nvs: %d at ID %d\n", bytes_written, i);
	}
	printk("NVS offset: %08x\n", storage.offset);
	printk("NVS ate_wra: %08x\n", storage.ate_wra);
	printk("NVS data_wra: %08x\n", storage.data_wra);
	printk("NVS Sector Size: %u\n", storage.sector_size);
	printk("NVS sector_count: %u\n", storage.sector_count);
	printk("NVS write_block_size: %u\n", storage.write_block_size);
	printk("NVS ready: %d\n", storage.ready);
  freespace = nvs_calc_free_space(&storage);
	printk("Remaining free space in nvs sector is %d Bytes\n", freespace);


}
